======================
Deploying applications
======================

This section contains a detailed overview on how shpkpr manages deployment of applications to Marathon. Each available deployment strategy is documented in-depth, both at a high level and with detailed API documentation.

.. toctree::
   :maxdepth: 1

   strategies/standard
   strategies/bluegreen
